=========
Changelog
=========

1.1.0 (2019-11-21)
==================

* Added ``privates.fields.PrivateMediaImageField`` - thanks to @GerjonM
* Support dropped for Django 2.0 (EOL)
* Support dropped for Python 3.4 (EOL)

Most likely this will still work on Python 3.4 and Django 2.0, however, it's
not explicitly listed in the CI build anymore, so use on your own risk.
